@@ -76,8 +76,8 @@ save pi
 !   Uncomment one of the following two lines, preferably the first if it is
 !   accepted by the compiler.
 
-data pi/ z'400921FB54442D18', z'3CA1A62633145C07'/
-! data pi/ 3.1415926535897931D+00,  1.2246467991473532D-16/
+!data pi/ z'400921FB54442D18', z'3CA1A62633145C07'/
+ data pi/ 3.1415926535897931D+00,  1.2246467991473532D-16/
 
 !   Check if both X and Y are zero.
 
@@ -552,27 +552,27 @@ save cs, pi
 !   Uncomment one of the following two sets of lines, preferably the first set
 !   if it is accepted by the compiler.
 
-data cs/ &
-  z'3FEF6297CFF75CB0',  z'3C7562172A361FD3', &
-  z'3FC8F8B83C69A60B',  z'BC626D19B9FF8D82', &
-  z'3FED906BCF328D46',  z'3C7457E610231AC2', &
-  z'3FD87DE2A6AEA963',  z'BC672CEDD3D5A610', &
-  z'3FEA9B66290EA1A3',  z'3C39F630E8B6DAC8', &
-  z'3FE1C73B39AE68C8',  z'3C8B25DD267F6600', &
-  z'3FE6A09E667F3BCD',  z'BC8BDD3413B26456', &
-  z'3FE6A09E667F3BCD',  z'BC8BDD3413B26456' /
-data pi/ z'400921FB54442D18',  z'3CA1A62633145C07'/
+!data cs/ &
+!  z'3FEF6297CFF75CB0',  z'3C7562172A361FD3', &
+!  z'3FC8F8B83C69A60B',  z'BC626D19B9FF8D82', &
+!  z'3FED906BCF328D46',  z'3C7457E610231AC2', &
+!  z'3FD87DE2A6AEA963',  z'BC672CEDD3D5A610', &
+!  z'3FEA9B66290EA1A3',  z'3C39F630E8B6DAC8', &
+!  z'3FE1C73B39AE68C8',  z'3C8B25DD267F6600', &
+!  z'3FE6A09E667F3BCD',  z'BC8BDD3413B26456', &
+!  z'3FE6A09E667F3BCD',  z'BC8BDD3413B26456' /
+!data pi/ z'400921FB54442D18',  z'3CA1A62633145C07'/
 
-! data cs/ &
-!    9.8078528040323043D-01,   1.8546939997825006D-17, &
-!    1.9509032201612828D-01,  -7.9910790684617313D-18, &
-!    9.2387953251128674D-01,   1.7645047084336677D-17, &
-!    3.8268343236508978D-01,  -1.0050772696461588D-17, &
-!    8.3146961230254524D-01,   1.4073856984728024D-18, &
-!    5.5557023301960218D-01,   4.7094109405616768D-17, &
-!    7.0710678118654757D-01,  -4.8336466567264567D-17, &
-!    7.0710678118654757D-01,  -4.8336466567264567D-17/
-! data pi / 3.1415926535897931D+00,  1.2246467991473532D-16/
+ data cs/ &
+    9.8078528040323043D-01,   1.8546939997825006D-17, &
+    1.9509032201612828D-01,  -7.9910790684617313D-18, &
+    9.2387953251128674D-01,   1.7645047084336677D-17, &
+    3.8268343236508978D-01,  -1.0050772696461588D-17, &
+    8.3146961230254524D-01,   1.4073856984728024D-18, &
+    5.5557023301960218D-01,   4.7094109405616768D-17, &
+    7.0710678118654757D-01,  -4.8336466567264567D-17, &
+    7.0710678118654757D-01,  -4.8336466567264567D-17/
+ data pi / 3.1415926535897931D+00,  1.2246467991473532D-16/
 
 if (a(1) .eq. 0.d0) then
   x(1) = 1.d0
@@ -930,8 +930,8 @@ save al2
 !   Uncomment one of the following two lines, preferably the first if it is
 !   accepted by the compiler.
 
-data al2 / z'3FE62E42FEFA39EF',  z'3C7ABC9E3B39803F'/
-! data al2/ 6.9314718055994529D-01,  2.3190468138462996D-17/
+!data al2 / z'3FE62E42FEFA39EF',  z'3C7ABC9E3B39803F'/
+ data al2/ 6.9314718055994529D-01,  2.3190468138462996D-17/
 
 !   Check for overflows and underflows.
 
@@ -1355,8 +1355,8 @@ save al2
 !   Uncomment one of the following two lines, preferably the first if it is
 !   accepted by the compiler.
 
-data al2 / z'3FE62E42FEFA39EF',  z'3C7ABC9E3B39803F'/
-! data al2/ 6.9314718055994529D-01,  2.3190468138462996D-17/
+!data al2 / z'3FE62E42FEFA39EF',  z'3C7ABC9E3B39803F'/
+ data al2/ 6.9314718055994529D-01,  2.3190468138462996D-17/
 
 if (a(1) .le. 0.d0) then
   write (6, 1)
@@ -1930,8 +1930,8 @@ save pic
 !   Uncomment one of the following two lines, preferably the first if it is
 !   accepted by the compiler.
 
-data pic/ z'400921FB54442D18', z'3CA1A62633145C07'/
-! data pic/ 3.1415926535897931D+00,  1.2246467991473532D-16/
+!data pic/ z'400921FB54442D18', z'3CA1A62633145C07'/
+ data pic/ 3.1415926535897931D+00,  1.2246467991473532D-16/
 
 pi(1) = pic(1)
 pi(2) = pic(2)
